import click
from .index_selection import *

import logging
logger = logging.getLogger(__name__)

@cli.group('close')
@click.pass_context
def close(ctx):
    """Close indices"""
close.add_command(indices)



import click
from .index_selection import *

import logging
logger = logging.getLogger(__name__)

@cli.group('alias')
@click.option('--name', help="Alias name", type=str)
@click.option('--remove', is_flag=True, show_default=True, expose_value=True,
            help='Remove from alias rather than add.')
@click.pass_context
def alias(ctx, name, remove):
    """Index Aliasing"""
    if not name:
        click.echo('{0}'.format(ctx.get_help()))
        click.echo(click.style('Missing required parameter --name', fg='red', bold=True))
        sys.exit(1)
alias.add_command(indices)



import click
from .index_selection import *

import logging
logger = logging.getLogger(__name__)

@cli.group('replicas')
@click.option('--count', type=int, expose_value=True,
            help='Number of replicas the indices should have.')
@click.pass_context
def replicas(ctx, count):
    """Replica Count Per-shard"""
    if count == None: # Have to do this since 0 is valid
        click.echo('{0}'.format(ctx.get_help()))
        click.echo(click.style('Missing required parameter --count', fg='red', bold=True))
        sys.exit(1)
replicas.add_command(indices)



from .utils import *
from .filter import *
import elasticsearch
import logging
logger = logging.getLogger(__name__)

def delete_indices(client, indices):
    """
    Delete the indicated indices, including closed indices.

    :arg client: The Elasticsearch client connection
    :arg indices: A list of indices to act on
    :rtype bool:
    """
    indices = ensure_list(indices)
    try:
        logger.info("Deleting indices as a batch operation:")
        for i in indices:
            logger.info("---deleting index {0}".format(i))
        client.indices.delete(index=to_csv(indices))
        return True
    except Exception:
        logger.error("Error deleting one or more indices.  Check logs for more information.")
        return False

def delete(client, indices):
    """
    Helper method called by the CLI.

    :arg client: The Elasticsearch client connection
    :arg indices: A list of indices to act on
    """
    return delete_indices(client, indices)



import click
from .index_selection import *

import logging
logger = logging.getLogger(__name__)

@cli.group('optimize')
@click.option('--delay', type=int, default=0, show_default=True, expose_value=True,
            help='Pause *n* seconds after optimizing an index.')
@click.option('--max_num_segments', type=int, default=2, show_default=True,
            expose_value=True,
            help='Merge to this number of segments per shard.')
@click.option('--request_timeout', type=int, default=21600, show_default=True,
            expose_value=True,
            help='Allow this many seconds before the transaction times out.')
@click.pass_context
def optimize(ctx, delay, max_num_segments, request_timeout):
    """Optimize Indices"""
optimize.add_command(indices)



import os
import re
import sys
from setuptools import setup

# Utility function to read from file.
def fread(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

def get_version():
    VERSIONFILE="curator/_version.py"
    verstrline = fread(VERSIONFILE).strip()
    vsre = r"^__version__ = ['\"]([^'\"]*)['\"]"
    mo = re.search(vsre, verstrline, re.M)
    if mo:
        VERSION = mo.group(1)
    else:
        raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))
    build_number = os.environ.get('CURATOR_BUILD_NUMBER', None)
    if build_number:
        return VERSION + "b{}".format(build_number)
    return VERSION

def get_install_requires():
    res = ['elasticsearch>=1.0.0,<2.0.0' ]
    res.append('click>=3.3')
    return res

setup(
    name = "elasticsearch-curator",
    version = get_version(),
    author = "Aaron Mildenstein",
    author_email = "aaron@mildensteins.com",
    description = "Tending your Elasticsearch indices",
    long_description=fread('README.md'),
    url = "http://github.com/elastic/curator",
    download_url = "https://github.com/elastic/curator/tarball/v" + get_version(),
    license = "Apache License, Version 2.0",
    install_requires = get_install_requires(),
    keywords = "elasticsearch time-series indexed index-expiry",
    packages = ["curator", "curator.api", "curator.cli"],
    include_package_data=True,
    entry_points = {
        "console_scripts" : ["curator = curator.curator:main",
                             "es_repo_mgr = curator.es_repo_mgr:main"]
    },
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: Apache Software License",
    ],
    test_suite = "test.run_tests.run_all",
    tests_require = ["mock", "nose", "coverage", "nosexcover"]
)
